diff finch/gntidle.c @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 0e3a8505ebbe
children 66dff3dfdea6
line wrap: on
line diff
--- a/finch/gntidle.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/finch/gntidle.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,7 +1,7 @@
 /*
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -33,12 +33,12 @@
 	return gnt_wm_get_idle_time();
 }
 
-static GaimIdleUiOps ui_ops =
+static PurpleIdleUiOps ui_ops =
 {
 	finch_get_idle_time
 };
 
-GaimIdleUiOps *
+PurpleIdleUiOps *
 finch_idle_get_ui_ops()
 {
 	return &ui_ops;
@@ -1,7 +1,7 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.